# ApiExperiment

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | Output. Unique experiment ID. Generated by API server. | [optional] 
**name** | **str** | Required input field. Unique experiment name provided by user. | [optional] 
**description** | **str** |  | [optional] 
**created_at** | **datetime** | Output. The time that the experiment created. | [optional] 
**resource_references** | [**list[ApiResourceReference]**](ApiResourceReference.md) | Optional input field. Specify which resource this run belongs to. For Experiment, the only valid resource reference is a single Namespace. | [optional] 
**storage_state** | [**ApiExperimentStorageState**](ApiExperimentStorageState.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


